package com.jjt.emp.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.emp.domain.TwinEmpCalc;
import com.jjt.emp.service.ITwinEmpCalcService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 员工产量统计Controller
 *
 * @author wukai
 * @date 2025-01-18
 */
@Api(tags="员工产量统计")
@RestController
@RequestMapping("/emp/empCalc")
public class TwinEmpCalcController extends BaseController{
    @Resource
    private ITwinEmpCalcService twinEmpCalcService;

    /**
     * 查询员工产量统计列表
     */
    @ApiOperation("查询员工产量统计列表")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:list')")
    @GetMapping("/list")
    public TableDataInfo list(TwinEmpCalc twinEmpCalc)
    {
        startPage();
        List<TwinEmpCalc> list = twinEmpCalcService.selectTwinEmpCalcList(twinEmpCalc);
        return getDataTable(list);
    }

    /**
     * 导出员工产量统计列表
     */
    @ApiOperation("导出员工产量统计列表")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:export')")
    @Log(title = "员工产量统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TwinEmpCalc twinEmpCalc)
    {
        List<TwinEmpCalc> list = twinEmpCalcService.selectTwinEmpCalcList(twinEmpCalc);
        ExcelUtil<TwinEmpCalc> util = new ExcelUtil<TwinEmpCalc>(TwinEmpCalc.class);
        util.exportExcel(response, list, "员工产量统计数据");
    }

    /**
     * 获取员工产量统计详细信息
     */
    @ApiOperation("获取员工产量统计详细信息")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:query')")
    @GetMapping(value = "/{calcId}")
    public AjaxResult getInfo(@PathVariable("calcId") Long calcId)
    {
        return success(twinEmpCalcService.selectTwinEmpCalcByCalcId(calcId));
    }

    /**
     * 新增员工产量统计
     */
    @ApiOperation("新增员工产量统计")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:add')")
    @Log(title = "员工产量统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TwinEmpCalc twinEmpCalc)
    {
        return toAjax(twinEmpCalcService.insertTwinEmpCalc(twinEmpCalc));
    }

    /**
     * 修改员工产量统计
     */
    @ApiOperation("修改员工产量统计")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:edit')")
    @Log(title = "员工产量统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TwinEmpCalc twinEmpCalc)
    {
        return toAjax(twinEmpCalcService.updateTwinEmpCalc(twinEmpCalc));
    }

    /**
     * 删除员工产量统计
     */
    @ApiOperation("删除员工产量统计")
    @PreAuthorize("@ss.hasPermi('emp:empCalc:remove')")
    @Log(title = "员工产量统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{calcIds}")
    public AjaxResult remove(@PathVariable Long[] calcIds)
    {
        return toAjax(twinEmpCalcService.deleteTwinEmpCalcByCalcIds(calcIds));
    }
}
